package fms

import (
	"hongze/fms_api/global"
	"time"
)

// ContractServiceTemplate 合同服务模板表
type ContractServiceTemplate struct {
	ServiceTemplateId int       `gorm:"primaryKey;column:service_template_id"`
	ProductId         string    `description:"产品id"`
	Pid               int       `description:"父级id"`
	Title             string    `description:"套餐名称"`
	Value             string    `description:"对应的数据"`
	SelectType        string    `description:"选择器类型，单选还是多选，radio；单选：checkbox"`
	SelectName        string    `description:"选择器名称"`
	TableValue        string    `description:"表格数据，用于word生成时的json数据"`
	Remark            string    `description:"表头备注"`
	ChartPermissionId int       `description:"权限id"`
	CreateTime        time.Time `description:"创建时间"`
	ModifyTime        time.Time `description:"修改时间"`
}

type ContractServiceTemplateMapItems struct {
	ServiceTemplateId int    `description:"套餐模板ID"`
	ProductId         int    `description:"产品id"`
	Pid               int    `description:"父级id"`
	Title             string `description:"套餐名称"`
	Value             string `description:"对应的数据"`
	SelectType        string `description:"选择器类型，单选还是多选，radio；单选：checkbox"`
	SelectName        string `description:"选择器名称"`
	ChartPermissionId int    `description:"权限id"`
	Children          []*ContractServiceTemplateMapItems
	Detail            []*ContractServiceDetail
}

// ContractServiceListReq CRM系统合同套餐-列表请求体
type ContractServiceListReq struct {
	ProductId int `json:"product_id" form:"product_id" binding:"omitempty" description:"产品: 1-FICC; 2-权益"`
}

func GetContractServiceTemplateMapByProductId(productId int) (items []*ContractServiceTemplateMapItems, err error) {
	items = make([]*ContractServiceTemplateMapItems, 0)
	err = global.DEFAULT_MYSQL.Model(ContractServiceTemplate{}).
		Where("product_id = ? AND pid = 0 AND is_delete = 0", productId).
		Find(&items).Error
	return
}

func GetContractServiceTemplateMapByParentId(parentId int) (items []*ContractServiceTemplateMapItems, err error) {
	items = make([]*ContractServiceTemplateMapItems, 0)
	err = global.DEFAULT_MYSQL.Model(ContractServiceTemplate{}).
		Where("pid = ? AND is_delete = 0", parentId).
		Find(&items).Error
	return
}

// GetContractServiceTemplateById 主键获取合同套餐模板
func GetContractServiceTemplateById(templateId int) (item *ContractServiceTemplate, err error) {
	err = global.DEFAULT_MYSQL.Model(ContractServiceTemplate{}).
		Where("service_template_id = ?", templateId).
		First(&item).Error
	return
}
